@@ -139,7 +139,8 @@ class Cardlist(list):
 
                 parameters_conditions = (
                         # tag
-                        (tag, f"(SELECT true FROM tags WHERE card_id=cards.id AND tag='{tag}')"),
+                        # the count(1) gives 1 if the record exists else 0
+                        (tag, f"(SELECT count(1) FROM tags WHERE card_id=cards.id AND tag='{tag}')"),
                         # date conditions
                         (created_after, f"create_date > {TODAY + (created_after or 0)}"),
                         (created_before, f"create_date < {TODAY + (created_before or 0)}"),
