@@ -2,7 +2,8 @@
 
 import sqlite3 as _sqlite3
 from vinca._cardlist import Cardlist as _Cardlist
-from vinca._config import collection_path, __file__
+import vinca._config
+from vinca._config import collection_path
 from pathlib import Path as _Path
 
 from rich import print as _print
@@ -22,7 +23,12 @@ if not collection_path.exists():
 
 # create default collection
 _cursor = _sqlite3.connect(collection_path).cursor()
-col = collection = _Cardlist(_cursor)
+all_cards = _Cardlist(_cursor)
+globals()['-a'] = all_cards
+col = all_cards
+for _tag in vinca._config.hidden_tags:
+    col = col.filter(tag = _tag, invert = True)
+del all_cards
 
 # The "tutorial" is just a deck of cards used to teach the basics of vinca
 _tutorial_cursor = _sqlite3.connect(_tutorial_path).cursor()
@@ -32,19 +38,19 @@ tutorial = _Cardlist(_tutorial_cursor)
 # this is so that ```vinca col review``` can be written as ```vinca review```
 _methods = ('browse', 'count', 'filter', 'find', 'findall', 'review', 'sort', 'purge', 'basic', 'verses', 'stats')
 for _method_name in _methods:
-    globals()[_method_name] = getattr(collection, _method_name)
+    globals()[_method_name] = getattr(col, _method_name)
 
-globals()['1'] = lambda: collection[1]
+globals()['1'] = lambda: col[1]
 globals()['1'].__doc__ = "most recent card"
-globals()['2'] = lambda: collection[2]
+globals()['2'] = lambda: col[2]
 globals()['2'].__doc__ = "second most recent card"
-globals()['3'] = lambda: collection[3]
+globals()['3'] = lambda: col[3]
 globals()['3'].__doc__ = "third most recent card"
 
 
 def edit_config():
     from subprocess import run
-    run(['vim', __file__])
+    run(['vim', vinca._config.__file__])
 
 
 def help():
