@@ -9,5 +9,5 @@ def today():
 class JulianDate(float):
         
         def __str__(self):
-            return conn.execute("select datetime(? - 0.5)", (float(self),)).fetchone()[0][:10]
+            return conn.execute("select datetime(? - 0.5)", (float(self),)).fetchone()[0][:10] + f'     write this on the command line as {int(self) - today()}'
 
